==> remmina_1.4.29+dfsg.orig.tar.xz: Remmina-v1.4.29/.gitlab/issue_templates/Default.md <==
> :exclamation: **[The Remmina project is looking for new maintainers](https://remmina.org/looking-for-maintainers/)**, and it's not actively updated.

**Make sure the problem exists on the [![latest Remmina version(s)](https://repology.org/badge/latest-versions/remmina.svg)](https://repology.org/project/remmina/versions) first, \
and keep trying to reproduce it on any later versions** :)

* Reporting back greatly increases the attention and hope of fixing your issue.

Do not use Gitlab for support requests, you can ask questions on:

* IRC, on libera.chat, in the #remmina channel, or use a [web client](https://web.libera.chat/?nick=remminer|?#remmina).
* [Matrix](https://riot.im/app/#/group/+remmina:matrix.org)
* [Reddit](https://reddit.com/r/Remmina) :(

For enhancement requests select the proper Issue template in the above drop-down box.

## Problem Description

Write a detailed description of the problem.

### What is the expected correct behavior?

(What you want to see instead.)

## Remote System Description

* Server (OS name and version):
* Special notes regarding the remote system (i.e. gateways, tunnel, etc.):

### Relevant logs and/or screenshots

<!-- (Paste any relevant logs - please use code blocks (```) to format ```console output, logs, and code``` as it's very hard to read otherwise.) -->

## Debugging documentation

Please see [Remmina debugging](https://gitlab.com/Remmina/Remmina/-/wikis/Usage/Remmina-debugging)

## Local System Description

* Client (OS name and version):
* Remmina version ( ```remmina --version``` ):
* Installation(s):
  - [X] Distribution package.
  - [ ] PPA.
  - [ ] Snap.
  - [ ] Flatpak.
  - [ ] Compiled from sources.
  - [ ] Other - detail:
* Desktop environment (GNOME, Unity, KDE, ..):
* Plugin(s):
  - [X] RDP - freerdp version ( ```xfreerdp --version``` ):
  - [ ] VNC
  - [ ] SSH
  - [ ] SFTP
  - [ ] SPICE
  - [ ] WWW
  - [ ] EXEC
  - [ ] Other (please specify):
* GTK back-end (Wayland, Xorg):
* Optional: Include the output of the following commands at the end of this text:

  - `remmina --full-version`

<!-- ( Paste after the `shell` line ) -->
```shell

```

  - `sudo lshw -C video`

<!-- ( Paste after the `shell` line ) -->
```shell

```

  - `uname -a`

<!-- ( Paste after the `shell` line ) -->
```shell

```

### Contributions

In return, or to fix this issue, I'd be willing to:

 - [ ] Fix this myself.
 - [ ] [Donate](https://remmina.org/donations/) ___ and/or have donated ___ towards fixing it.
 - [ ] Take a donation of ___ to fix it.
 - [ ] Update the [documentation](https://remmina.gitlab.io/remminadoc.gitlab.io/md__c_o_n_t_r_i_b_u_t_i_n_g.html).
 - [ ] Update the [wiki](https://gitlab.com/Remmina/Remmina/-/wikis/home).
 - [ ] Translate Remmina in my native language(s) (___) on [Hosted Weblate](https://hosted.weblate.org/projects/remmina/remmina/).

/label ~bug

==> remmina_1.4.35+dfsg.orig.tar.xz: Remmina-v1.4.35/.gitlab/issue_templates/Default.md <==
**Ensure the problem exists on the [![latest Remmina version(s)](https://repology.org/badge/latest-versions/remmina.svg)](https://repology.org/project/remmina/versions) first, \
and keep trying to reproduce it on any later versions** :)

* Reporting back greatly increases attention to and hope of fixing your issue.

Do not use GitLab for support requests, instead ask questions on:

* [Matrix](https://matrix.to/#/#remmina-room:matrix.org) (the best way to reach us)
* [Reddit](https://reddit.com/r/Remmina)
* IRC, on libera.chat, in the #remmina channel, or use a [web client](https://web.libera.chat/?nick=remminer|?#remmina).

For enhancement requests select the proper Issue template in the above drop-down box.

## Problem Description

Write a detailed description of the problem.

### What is the expected correct behavior?

(What you want to see instead.)

## Remote System Description

* Server (OS name and version):
* Special notes regarding the remote system (i.e. gateways, tunnel, etc.):

### Relevant logs and/or screenshots

<!-- (Paste any relevant logs - please use code blocks (```) to format ```console output, logs, and code``` as it's very hard to read otherwise.) -->

## Debugging documentation

Please see [Remmina debugging](https://gitlab.com/Remmina/Remmina/-/wikis/Usage/Remmina-debugging)

## Local System Description

* Client (OS name and version):
* Remmina version ( ```remmina --version``` ):
* Installation(s):
  - [X] Distribution package.
  - [ ] PPA.
  - [ ] Snap.
  - [ ] Flatpak.
  - [ ] Compiled from sources.
  - [ ] Other - detail:
* Desktop environment (GNOME, Unity, KDE, ..):
* Plugin(s):
  - [X] RDP - freerdp version ( ```xfreerdp --version``` ):
  - [ ] VNC
  - [ ] SSH
  - [ ] SFTP
  - [ ] SPICE
  - [ ] WWW
  - [ ] EXEC
  - [ ] Other (please specify):
* GTK backend (Wayland, Xorg):
* Optional: Include the output of the following commands at the end of this text:

  - `remmina --full-version`

<!-- ( Paste after the `shell` line ) -->
```shell

```

  - `sudo lshw -C video`

<!-- ( Paste after the `shell` line ) -->
```shell

```

  - `uname -a`

<!-- ( Paste after the `shell` line ) -->
```shell

```

### Contributions

In return, or to fix this issue, I'd be willing to:

 - [ ] Fix this myself.
 - [ ] [Donate](https://remmina.org/donations/) ___ and/or have donated ___ towards fixing it.
 - [ ] Take a donation of ___ to fix it.
 - [ ] Update the [documentation](https://remmina.gitlab.io/remminadoc.gitlab.io/md__c_o_n_t_r_i_b_u_t_i_n_g.html).
 - [ ] Update the [wiki](https://gitlab.com/Remmina/Remmina/-/wikis/home).
 - [ ] Translate Remmina in my native language(s) (___) on [Hosted Weblate](https://hosted.weblate.org/projects/remmina/remmina/).

/label ~bug
